<template>
  <div class="flow">
    <div class="content">
      <!--左侧工具栏-->
      <div id="stencil" />
      <div class="panel">
        <!--流程图工具栏-->
        <div class="toolbar">
          <tool-bar v-if="isReady" />
        </div>
        <!--流程图画板-->
        <div id="container" />
      </div>
      <!--右侧工具栏-->
      <div class="config">
        <config-panel v-if="isReady" />
      </div>
    </div>
  </div>
</template>
<script>
import "./index.css";
import FlowGraph from "./graph";
import ToolBar from "./components/ToolBar/index.vue";
import ConfigPanel from "./components/ConfigPanel/index.vue";
import { $, getImg, getContainerSize } from "@/utils/util";
// import './shape'
import { customPorts, basicPorts } from "./graph/ports";
import graphData from "./graph/data/data";
export default {
  name:'x6_edit',
  data() {
    return {
      isReady: false,
      destroyFn: null,
    };
  },
  components: { ToolBar, ConfigPanel },
  mounted() {
    this.destroyFn = this.initGraph();
  },
  destroyed() {
    // 移除监听、销毁画布、资源回收
    this.destroyFn();
  },
  methods: {
    initGraph() {
      const graph = FlowGraph.init(
        $("#container"),
        $("#container").getBoundingClientRect().width,
        $("#container").getBoundingClientRect().height
      );
      this.isReady = true;
      graph.fromJSON(graphData);
      setTimeout(() => {
            graph.zoomToFit()
        }, 500);
      let option = {
        stencilGraphWidth: 260,
        collapsable: true,
        groups: [
          {
            name: "basic",
            title: "基础节点",
            graphHeight: 370,
          },
          {
            name: "custom-image",
            title: "系统设计图",
            graphHeight: 600,
          },
        ],
      };
      const stencil = FlowGraph.initStencil(option);
      this.initShape(graph, stencil);
      // const resizeFn = () => {
      //   const { width, height } = getContainerSize($('.panel'))
      //   graph.resize(width, height - 38)
      // }
      // resizeFn()
      // window.addEventListener('resize', resizeFn)
      return () => {
        // window.removeEventListener('resize', resizeFn)
        graph.dispose();
      };
    },
    initShape(graph, stencil) {
      // 基础节点
      const r1 = graph.createNode({
        shape: "flow-chart-rect1",
        attrs: {
          body: {
            rx: 24,
            ry: 24,
          },
          text: {
            text: "起始节点",
          },
        },
      });

      const r2 = graph.createNode({
        shape: "flow-chart-rect",
        attrs: {
          text: {
            text: "流程节点",
          },
        },
      });
      const r3 = graph.createNode({
        shape: "flow-chart-rect",
        width: 52,
        height: 52,
        angle: 45,
        attrs: {
          "edit-text": {
            style: {
              transform: "rotate(-45deg)",
            },
          },
          text: {
            text: "判断节点",
            transform: "rotate(-45deg)",
          },
        },
        ports: {
          groups: {
            top: {
              position: {
                name: "top",
                args: {
                  dx: -26,
                },
              },
            },
            right: {
              position: {
                name: "right",
                args: {
                  dy: -26,
                },
              },
            },
            bottom: {
              position: {
                name: "bottom",
                args: {
                  dx: 26,
                },
              },
            },
            left: {
              position: {
                name: "left",
                args: {
                  dy: 26,
                },
              },
            },
          },
        },
      });
      const r4 = graph.createNode({
        shape: "flow-chart-rect",
        width: 70,
        height: 70,
        attrs: {
          body: {
            rx: '50%',
            ry: '50%',
          },
          text: {
            text: "链接节点",
          },
        },
      });
      const r5 = graph.createNode({
        shape: "orNode",
        width: 70,
        height: 70,
        
      });
      const r6 = graph.createNode({
        shape: "andNode",
        width: 70,
        height: 70,
        
      });

      // 系统设计图
      const imgs = [
        {
          image: getImg("ldb.png"),
        },
        {
          image: getImg("wft1.png"),
        },
        {
          image: getImg("wft2.png"),
        },
        {
          image: getImg("wft3.png"),
        },
        {
          image: getImg("wft4.png"),
        },
        {
          image: getImg("wft5.png"),
        },
        {
          image: getImg("lqt.png"),
        },
        {
          image: getImg("lqb-o.png"),
        },
        {
          image: getImg("ldb-o.png"),
        },
        {
          image: getImg("bh.png"),
        },
        {
          image: getImg("f1.png"),
        },
        {
          image: getImg("f2.png"),
        },
        {
          image: getImg("f3.png"),
        },
      ];
      const imgNodes = imgs.map((item) => {
        return graph.createNode({
          shape: "image", //可选值：Rect Circle Ellipse Polygon Polyline Path Image HTML TextBlock BorderedImage EmbeddedImage InscribedImage Cylinder
          imageUrl: item.image,
          attrs: {
            image: {
              // fill: 'yellow',
            },
          },
          width: 52,
          height: 52,
          ports: { ...customPorts },
        });
      });
      stencil.load([r1, r2, r3, r4,r5,r6], "basic");
      stencil.load(imgNodes, "custom-image");
    },
  },
};
</script>
<style>
.x6-widget-snapline-vertical {
  border-right-color: #ff4e50 !important;
}
.x6-widget-snapline-horizontal {
  border-bottom-color: #ff4e50 !important;
}
.x6-widget-selection-box {
  border: 1px dashed #5f95ff;
  margin-top: -3px;
  margin-left: -3px;
}
.x6-widget-selection-inner {
  border: 1px dashed #5f95ff;
}

@keyframes stroke {
  100% {
    stroke-dashoffset: -400;
  }
}
.animate-text1,
.animate-text2,
.animate-text3,
.animate-text4 {
  font-weight: bold;
  fill: none;
  stroke-width: 2px;
  stroke-dasharray: 90 310;
  animation: stroke 3s infinite linear;
}
.animate-text1 {
  stroke: #873bf4;
  text-shadow: 0 0 2px #873bf4;
  animation-delay: -1.5s;
}
.animate-text2 {
  stroke: #ff6e06;
  text-shadow: 0 0 2px #ff6e06;
  animation-delay: -3s;
}
</style>
